Module shellcode

Module shellcode 

Shellcode loader with symbol resolution and position-independent code support

Structs

LoadedShellcode
Represents loaded executable shellcode in memory
ShellcodeBuilder
Builder for configuring and loading shellcode
SymbolRelocation
Represents a symbol that needs to be resolved and patched into the shellcode

Enums

LoaderError
Errors that can occur during shellcode loading or execution

Traits

ShellcodeSource
Trait for types that can be converted to shellcode bytes

Functions

invalidate_icache
Invalidates the instruction cache for a memory range
load
Unified helper to load shellcode from bytes or ARM64 instructions