pub trait ShellcodeSource {
// Required method
fn into_bytes(self) -> Vec<u8> ⓘ;
}Expand description
Trait for types that can be converted to shellcode bytes
pub trait ShellcodeSource {
// Required method
fn into_bytes(self) -> Vec<u8> ⓘ;
}Trait for types that can be converted to shellcode bytes