pub enum ProtectionError {
QueryFailed(usize),
InvalidAddress(usize),
ProtectionFailed(i32),
}Expand description
Errors that can occur during protection queries or modifications
Variants
QueryFailed(usize)
Failed to query memory region information from the kernel
InvalidAddress(usize)
The address is invalid or not mapped
ProtectionFailed(i32)
Failed to change memory protection