Module patch

Module patch 

Stealth memory patching

Uses mach_vm_remap to create writable aliases of code pages, avoiding detectable vm_protect calls on the original code segment.

Structs

Patch
Represents an applied memory patch

Enums

PatchError
Errors that can occur during patching operations

Functions

apply
Applies a hex string patch at a relative virtual address (RVA)
apply_asm
Applies an assembly patch at a relative virtual address (RVA)
apply_asm_in_cave
Applies an assembly patch using a code cave
apply_at_address
Applies a patch at an absolute address
apply_in_cave
Applies a hex string patch using a code cave
invalidate_icache
Invalidates the instruction cache for a memory range