Shellcode loader with symbol resolution and position-independent code support
Structs
- Loaded
Shellcode - Represents loaded executable shellcode in memory
- Shellcode
Builder - Builder for configuring and loading shellcode
- Symbol
Relocation - Represents a symbol that needs to be resolved and patched into the shellcode
Enums
- Loader
Error - Errors that can occur during shellcode loading or execution
Traits
- Shellcode
Source - Trait for types that can be converted to shellcode bytes
Functions
- invalidate_
icache ⚠ - Invalidates the instruction cache for a memory range
- load
- Unified helper to load shellcode from bytes or ARM64 instructions