Stealth memory patching
Uses mach_vm_remap to create writable aliases of code pages, avoiding detectable vm_protect calls on the original code segment.
Structs
- Patch
- Represents an applied memory patch
Enums
- Patch
Error - Errors that can occur during patching operations
Functions
- apply
- Applies a hex string patch at a relative virtual address (RVA)
- apply_
asm - Applies an assembly patch at a relative virtual address (RVA)
- apply_
asm_ in_ cave - Applies an assembly patch using a code cave
- apply_
at_ address - Applies a patch at an absolute address
- apply_
in_ cave - Applies a hex string patch using a code cave
- invalidate_
icache ⚠ - Invalidates the instruction cache for a memory range