pub struct SessionCache { /* private fields */ }Expand description
TLS session ticket cache.
Stores session tickets per host to enable session resumption. Session tickets are provided by the server during TLS handshake and can be reused for subsequent connections.
Implementations
Sourceimpl SessionCache
impl SessionCache
Sourcepub fn with_max_age(max_age: Duration) -> Self
pub fn with_max_age(max_age: Duration) -> Self
Create a session cache with custom max age.
Sourcepub fn store_ticket(
&self,
host: &str,
ticket_data: Vec<u8>,
max_age: Option<Duration>,
)
pub fn store_ticket( &self, host: &str, ticket_data: Vec<u8>, max_age: Option<Duration>, )
Store a session ticket for a host.
Sourcepub fn get_ticket(&self, host: &str) -> Option<Vec<u8>>
pub fn get_ticket(&self, host: &str) -> Option<Vec<u8>>
Get a session ticket for a host (if valid and not expired).
Sourcepub fn cleanup_expired(&self)
pub fn cleanup_expired(&self)
Remove expired tickets.